import { checker } from 'addons';
import { Message as Message$1, RestartProps as RestartProps$1 } from 'types';

type PluginJson = {
    uid: string;
    name: string;
    description: string;
    version: string;
    authors?: string[];
    dependencies?: Record<string, string | "*">;
    compatibleVersions?: {
        min?: string | "*";
        max?: string | "*";
    } & ({
        min: string;
    } | {
        max: string;
    });
};
interface Plugin extends PluginJson {
    init(props: PluginProps): void;
    restart(): void;
}
type PluginProps = {
    onMessage(props: Message$1): void;
    checker: typeof checker;
};

type MessageType = "critical" | "warning" | "info" | "debug";
type Message = {
    code?: number;
    type: MessageType;
    details?: Record<string, any> | string | number | boolean;
};

type RestartProps = {
    all?: boolean;
    uids?: string[];
};

declare function register(plugins: Plugin[]): void;

declare function restart(props?: RestartProps$1): void;

declare const mcore: {
    register: typeof register;
    restart: typeof restart;
};

export { mcore as default };
export type { Message, MessageType, Plugin, PluginJson, PluginProps, RestartProps };
